import Tabs from 'carbon-components/src/components/tabs/tabs';

export default function()
{
    Tabs.init();
    /*for (let el of document.querySelectorAll('[data-modal-target]'))
    {
        Modal.init(el);
    }*/
}
